# Plotting

`pymgcv.plot` provides plotting utilities for visualizing GAM models. Plotting is performed using matplotlib.

- For an overall plot of the partial effects of a gam model, use [`plot_gam`][pymgcv.plot.plot_gam].
- For more fine control over the plotting, specific terms can be plotted onto a single matplotlib axis, using the functions:
    * [`plot_continuous_1d`][pymgcv.plot.plot_continuous_1d]
    * [`plot_continuous_2d`][pymgcv.plot.plot_continuous_2d]
    * [`plot_categorical`][pymgcv.plot.plot_categorical]

::: pymgcv.plot.plot_gam
::: pymgcv.plot.plot_continuous_1d
::: pymgcv.plot.plot_continuous_2d
::: pymgcv.plot.plot_categorical
::: pymgcv.plot.plot_qq
::: pymgcv.plot.plot_residuals_vs_linear_predictor
::: pymgcv.plot.hexbin_residuals
